#-------------------------------------------------------------------------------
MACRO (ZLIB_SET_LIB_OPTIONS libtarget defaultlibname libtype)
  set (libname "${defaultlibname}")

  if (NOT WIN32)
    # On unix-like platforms the library is almost always called libz
    set (libname "z")
    set_target_properties (${libtarget} PROPERTIES OUTPUT_NAME z)
  endif (NOT WIN32)

  # message (STATUS "${libname} libtype: ${libtype}")
  HDF_SET_LIB_OPTIONS (${libtarget} ${libname} ${libtype})

  if (${libtype} MATCHES "SHARED")
    if (WIN32)
      set (LIBZLIB_VERSION ${ZLIB_PACKAGE_VERSION_MAJOR})
    else (WIN32)
      set (LIBZLIB_VERSION ${ZLIB_PACKAGE_VERSION})
    endif (WIN32)

    if (NOT CYGWIN)
      # This property causes shared libraries on Linux to have the full version
      # encoded into their final filename.  We disable this on Cygwin because
      # it causes cygz-${ZLIB_FULL_VERSION}.dll to be created when cygz.dll
      # seems to be the default.
      #
      # This has no effect with MSVC, on that platform the version info for
      # the DLL comes from the resource file win32/zlib1.rc
      set_target_properties (${libtarget} PROPERTIES VERSION ${LIBZLIB_VERSION})
    endif (NOT CYGWIN)
    set_target_properties (${libtarget} PROPERTIES SOVERSION ${LIBZLIB_VERSION})
  endif (${libtype} MATCHES "SHARED")

  #-- Apple Specific install_name for libraries
  if (APPLE)
    option (ZLIB_BUILD_WITH_INSTALL_NAME "Build with library install_name set to the installation path" OFF)
    if (ZLIB_BUILD_WITH_INSTALL_NAME)
      set_target_properties (${libtarget} PROPERTIES
          LINK_FLAGS "-current_version ${ZLIB_PACKAGE_VERSION} -compatibility_version ${ZLIB_PACKAGE_VERSION}"
          INSTALL_NAME_DIR "${CMAKE_INSTALL_PREFIX}/lib"
          BUILD_WITH_INSTALL_RPATH ${ZLIB_BUILD_WITH_INSTALL_NAME}
      )
    endif (ZLIB_BUILD_WITH_INSTALL_NAME)
  endif (APPLE)

ENDMACRO (ZLIB_SET_LIB_OPTIONS)

